Class: Aws::Chatbot::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Chatbot::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chatbot/client.rb
Overview
An API client for Chatbot. To construct a client, you need to configure a :region and :credentials.
client = Aws::Chatbot::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_chime_webhook_configuration(params = {}) ⇒ Types::CreateChimeWebhookConfigurationResult
Creates an AWS Chatbot configuration for Amazon Chime.
-
#create_microsoft_teams_channel_configuration(params = {}) ⇒ Types::CreateTeamsChannelConfigurationResult
Creates an AWS Chatbot configuration for Microsoft Teams.
-
#create_slack_channel_configuration(params = {}) ⇒ Types::CreateSlackChannelConfigurationResult
Creates an AWS Chatbot confugration for Slack.
-
#delete_chime_webhook_configuration(params = {}) ⇒ Struct
Deletes a Amazon Chime webhook configuration for AWS Chatbot.
-
#delete_microsoft_teams_channel_configuration(params = {}) ⇒ Struct
Deletes a Microsoft Teams channel configuration for AWS Chatbot.
-
#delete_microsoft_teams_configured_team(params = {}) ⇒ Struct
Deletes the Microsoft Teams team authorization allowing for channels to be configured in that Microsoft Teams team.
-
#delete_microsoft_teams_user_identity(params = {}) ⇒ Struct
Identifes a user level permission for a channel configuration.
-
#delete_slack_channel_configuration(params = {}) ⇒ Struct
Deletes a Slack channel configuration for AWS Chatbot.
-
#delete_slack_user_identity(params = {}) ⇒ Struct
Deletes a user level permission for a Slack channel configuration.
-
#delete_slack_workspace_authorization(params = {}) ⇒ Struct
Deletes the Slack workspace authorization that allows channels to be configured in that workspace.
-
#describe_chime_webhook_configurations(params = {}) ⇒ Types::DescribeChimeWebhookConfigurationsResult
Lists Amazon Chime webhook configurations optionally filtered by ChatConfigurationArn.
-
#describe_slack_channel_configurations(params = {}) ⇒ Types::DescribeSlackChannelConfigurationsResult
Lists Slack channel configurations optionally filtered by ChatConfigurationArn.
-
#describe_slack_user_identities(params = {}) ⇒ Types::DescribeSlackUserIdentitiesResult
Lists all Slack user identities with a mapped role.
-
#describe_slack_workspaces(params = {}) ⇒ Types::DescribeSlackWorkspacesResult
List all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot.
-
#get_account_preferences(params = {}) ⇒ Types::GetAccountPreferencesResult
Returns AWS Chatbot account preferences.
-
#get_microsoft_teams_channel_configuration(params = {}) ⇒ Types::GetTeamsChannelConfigurationResult
Returns a Microsoft Teams channel configuration in an AWS account.
-
#list_microsoft_teams_channel_configurations(params = {}) ⇒ Types::ListTeamsChannelConfigurationsResult
Lists all AWS Chatbot Microsoft Teams channel configurations in an AWS account.
-
#list_microsoft_teams_configured_teams(params = {}) ⇒ Types::ListMicrosoftTeamsConfiguredTeamsResult
Lists all authorized Microsoft Teams for an AWS Account.
-
#list_microsoft_teams_user_identities(params = {}) ⇒ Types::ListMicrosoftTeamsUserIdentitiesResult
A list all Microsoft Teams user identities with a mapped role.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify.
-
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN).
-
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN).
-
#update_account_preferences(params = {}) ⇒ Types::UpdateAccountPreferencesResult
Updates AWS Chatbot account preferences.
-
#update_chime_webhook_configuration(params = {}) ⇒ Types::UpdateChimeWebhookConfigurationResult
Updates a Amazon Chime webhook configuration.
-
#update_microsoft_teams_channel_configuration(params = {}) ⇒ Types::UpdateTeamsChannelConfigurationResult
Updates an Microsoft Teams channel configuration.
-
#update_slack_channel_configuration(params = {}) ⇒ Types::UpdateSlackChannelConfigurationResult
Updates a Slack channel configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
444 445 446 |
# File 'lib/aws-sdk-chatbot/client.rb', line 444 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1801 1802 1803 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1801 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1804 1805 1806 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1804 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1774 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Chatbot') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chatbot' context[:gem_version] = '1.16.0' Seahorse::Client::Request.new(handlers, context) end |
#create_chime_webhook_configuration(params = {}) ⇒ Types::CreateChimeWebhookConfigurationResult
Creates an AWS Chatbot configuration for Amazon Chime.
529 530 531 532 |
# File 'lib/aws-sdk-chatbot/client.rb', line 529 def create_chime_webhook_configuration(params = {}, = {}) req = build_request(:create_chime_webhook_configuration, params) req.send_request() end |
#create_microsoft_teams_channel_configuration(params = {}) ⇒ Types::CreateTeamsChannelConfigurationResult
Creates an AWS Chatbot configuration for Microsoft Teams.
644 645 646 647 |
# File 'lib/aws-sdk-chatbot/client.rb', line 644 def create_microsoft_teams_channel_configuration(params = {}, = {}) req = build_request(:create_microsoft_teams_channel_configuration, params) req.send_request() end |
#create_slack_channel_configuration(params = {}) ⇒ Types::CreateSlackChannelConfigurationResult
Creates an AWS Chatbot confugration for Slack.
744 745 746 747 |
# File 'lib/aws-sdk-chatbot/client.rb', line 744 def create_slack_channel_configuration(params = {}, = {}) req = build_request(:create_slack_channel_configuration, params) req.send_request() end |
#delete_chime_webhook_configuration(params = {}) ⇒ Struct
Deletes a Amazon Chime webhook configuration for AWS Chatbot.
767 768 769 770 |
# File 'lib/aws-sdk-chatbot/client.rb', line 767 def delete_chime_webhook_configuration(params = {}, = {}) req = build_request(:delete_chime_webhook_configuration, params) req.send_request() end |
#delete_microsoft_teams_channel_configuration(params = {}) ⇒ Struct
Deletes a Microsoft Teams channel configuration for AWS Chatbot
791 792 793 794 |
# File 'lib/aws-sdk-chatbot/client.rb', line 791 def delete_microsoft_teams_channel_configuration(params = {}, = {}) req = build_request(:delete_microsoft_teams_channel_configuration, params) req.send_request() end |
#delete_microsoft_teams_configured_team(params = {}) ⇒ Struct
Deletes the Microsoft Teams team authorization allowing for channels to be configured in that Microsoft Teams team. Note that the Microsoft Teams team must have no channels configured to remove it.
825 826 827 828 |
# File 'lib/aws-sdk-chatbot/client.rb', line 825 def delete_microsoft_teams_configured_team(params = {}, = {}) req = build_request(:delete_microsoft_teams_configured_team, params) req.send_request() end |
#delete_microsoft_teams_user_identity(params = {}) ⇒ Struct
Identifes a user level permission for a channel configuration.
852 853 854 855 |
# File 'lib/aws-sdk-chatbot/client.rb', line 852 def delete_microsoft_teams_user_identity(params = {}, = {}) req = build_request(:delete_microsoft_teams_user_identity, params) req.send_request() end |
#delete_slack_channel_configuration(params = {}) ⇒ Struct
Deletes a Slack channel configuration for AWS Chatbot
875 876 877 878 |
# File 'lib/aws-sdk-chatbot/client.rb', line 875 def delete_slack_channel_configuration(params = {}, = {}) req = build_request(:delete_slack_channel_configuration, params) req.send_request() end |
#delete_slack_user_identity(params = {}) ⇒ Struct
Deletes a user level permission for a Slack channel configuration.
906 907 908 909 |
# File 'lib/aws-sdk-chatbot/client.rb', line 906 def delete_slack_user_identity(params = {}, = {}) req = build_request(:delete_slack_user_identity, params) req.send_request() end |
#delete_slack_workspace_authorization(params = {}) ⇒ Struct
Deletes the Slack workspace authorization that allows channels to be configured in that workspace. This requires all configured channels in the workspace to be deleted.
930 931 932 933 |
# File 'lib/aws-sdk-chatbot/client.rb', line 930 def (params = {}, = {}) req = build_request(:delete_slack_workspace_authorization, params) req.send_request() end |
#describe_chime_webhook_configurations(params = {}) ⇒ Types::DescribeChimeWebhookConfigurationsResult
Lists Amazon Chime webhook configurations optionally filtered by ChatConfigurationArn
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
987 988 989 990 |
# File 'lib/aws-sdk-chatbot/client.rb', line 987 def describe_chime_webhook_configurations(params = {}, = {}) req = build_request(:describe_chime_webhook_configurations, params) req.send_request() end |
#describe_slack_channel_configurations(params = {}) ⇒ Types::DescribeSlackChannelConfigurationsResult
Lists Slack channel configurations optionally filtered by ChatConfigurationArn
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1050 1051 1052 1053 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1050 def describe_slack_channel_configurations(params = {}, = {}) req = build_request(:describe_slack_channel_configurations, params) req.send_request() end |
#describe_slack_user_identities(params = {}) ⇒ Types::DescribeSlackUserIdentitiesResult
Lists all Slack user identities with a mapped role.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1101 1102 1103 1104 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1101 def describe_slack_user_identities(params = {}, = {}) req = build_request(:describe_slack_user_identities, params) req.send_request() end |
#describe_slack_workspaces(params = {}) ⇒ Types::DescribeSlackWorkspacesResult
List all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1145 1146 1147 1148 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1145 def describe_slack_workspaces(params = {}, = {}) req = build_request(:describe_slack_workspaces, params) req.send_request() end |
#get_account_preferences(params = {}) ⇒ Types::GetAccountPreferencesResult
Returns AWS Chatbot account preferences.
1165 1166 1167 1168 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1165 def get_account_preferences(params = {}, = {}) req = build_request(:get_account_preferences, params) req.send_request() end |
#get_microsoft_teams_channel_configuration(params = {}) ⇒ Types::GetTeamsChannelConfigurationResult
Returns a Microsoft Teams channel configuration in an AWS account.
1210 1211 1212 1213 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1210 def get_microsoft_teams_channel_configuration(params = {}, = {}) req = build_request(:get_microsoft_teams_channel_configuration, params) req.send_request() end |
#list_microsoft_teams_channel_configurations(params = {}) ⇒ Types::ListTeamsChannelConfigurationsResult
Lists all AWS Chatbot Microsoft Teams channel configurations in an AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1283 1284 1285 1286 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1283 def list_microsoft_teams_channel_configurations(params = {}, = {}) req = build_request(:list_microsoft_teams_channel_configurations, params) req.send_request() end |
#list_microsoft_teams_configured_teams(params = {}) ⇒ Types::ListMicrosoftTeamsConfiguredTeamsResult
Lists all authorized Microsoft Teams for an AWS Account
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1327 def list_microsoft_teams_configured_teams(params = {}, = {}) req = build_request(:list_microsoft_teams_configured_teams, params) req.send_request() end |
#list_microsoft_teams_user_identities(params = {}) ⇒ Types::ListMicrosoftTeamsUserIdentitiesResult
A list all Microsoft Teams user identities with a mapped role.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1381 def list_microsoft_teams_user_identities(params = {}, = {}) req = build_request(:list_microsoft_teams_user_identities, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
1412 1413 1414 1415 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1412 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
1445 1446 1447 1448 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1445 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
1477 1478 1479 1480 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1477 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_account_preferences(params = {}) ⇒ Types::UpdateAccountPreferencesResult
Updates AWS Chatbot account preferences.
1520 1521 1522 1523 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1520 def update_account_preferences(params = {}, = {}) req = build_request(:update_account_preferences, params) req.send_request() end |
#update_chime_webhook_configuration(params = {}) ⇒ Types::UpdateChimeWebhookConfigurationResult
Updates a Amazon Chime webhook configuration.
1594 1595 1596 1597 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1594 def update_chime_webhook_configuration(params = {}, = {}) req = build_request(:update_chime_webhook_configuration, params) req.send_request() end |
#update_microsoft_teams_channel_configuration(params = {}) ⇒ Types::UpdateTeamsChannelConfigurationResult
Updates an Microsoft Teams channel configuration.
1678 1679 1680 1681 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1678 def update_microsoft_teams_channel_configuration(params = {}, = {}) req = build_request(:update_microsoft_teams_channel_configuration, params) req.send_request() end |
#update_slack_channel_configuration(params = {}) ⇒ Types::UpdateSlackChannelConfigurationResult
Updates a Slack channel configuration.
1765 1766 1767 1768 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1765 def update_slack_channel_configuration(params = {}, = {}) req = build_request(:update_slack_channel_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1794 1795 1796 |
# File 'lib/aws-sdk-chatbot/client.rb', line 1794 def waiter_names [] end |