Class: Aws::Chatbot::Types::ConfiguredTeam

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chatbot/types.rb

Overview

A Microsoft Teams team that is authorized with AWS Chatbot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#team_idString

The ID of the Microsoft Teams authorized with AWS Chatbot.

To get the team ID, you must perform the initial authorization flow with Microsoft Teams in the AWS Chatbot console. Then you can copy and paste the team ID from the console. For more information, see

Step 1: Configure a Microsoft Teams client][1

in the <i> AWS

Chatbot Administrator Guide</i>.

[1]: docs.aws.amazon.com/chatbot/latest/adminguide/teams-setup.html#teams-client-setup

Returns:

  • (String)


131
132
133
134
135
136
137
# File 'lib/aws-sdk-chatbot/types.rb', line 131

class ConfiguredTeam < Struct.new(
  :tenant_id,
  :team_id,
  :team_name)
  SENSITIVE = []
  include Aws::Structure
end

#team_nameString

The name of the Microsoft Teams Team.

Returns:

  • (String)


131
132
133
134
135
136
137
# File 'lib/aws-sdk-chatbot/types.rb', line 131

class ConfiguredTeam < Struct.new(
  :tenant_id,
  :team_id,
  :team_name)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_idString

The ID of the Microsoft Teams tenant.

Returns:

  • (String)


131
132
133
134
135
136
137
# File 'lib/aws-sdk-chatbot/types.rb', line 131

class ConfiguredTeam < Struct.new(
  :tenant_id,
  :team_id,
  :team_name)
  SENSITIVE = []
  include Aws::Structure
end