Class: Aws::Chatbot::Types::CreateSlackChannelConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chatbot/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:slack_channel_name]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_nameString

The name of the configuration.

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#guardrail_policy_arnsArray<String>

The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed AdministratorAccess policy is applied by default if this is not set.

Returns:

  • (Array<String>)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#iam_role_arnString

A user-defined role that AWS Chatbot assumes. This is not the service-linked role.

For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.

[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#logging_levelString

Logging levels include ERROR, INFO, or NONE.

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#slack_channel_idString

The ID of the Slack channel.

To get this ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#slack_channel_nameString

The name of the Slack channel.

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#slack_team_idString

The ID of the Slack workspace authorized with AWS Chatbot.

Returns:

  • (String)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#sns_topic_arnsArray<String>

The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.

Returns:

  • (Array<String>)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#tagsArray<Types::Tag>

A map of tags assigned to a resource. A tag is a string-to-string map of key-value pairs.

Returns:



310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end

#user_authorization_requiredBoolean

Enables use of a user role requirement in your chat configuration.

Returns:

  • (Boolean)


310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/aws-sdk-chatbot/types.rb', line 310

class CreateSlackChannelConfigurationRequest < Struct.new(
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :sns_topic_arns,
  :iam_role_arn,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end