Class: Aws::Chatbot::Types::CreateTeamsChannelConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::CreateTeamsChannelConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:channel_name, :team_name]
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID of the Microsoft Teams channel.
-
#channel_name ⇒ String
The name of the Microsoft Teams channel.
-
#configuration_name ⇒ String
The name of the configuration.
-
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails.
-
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes.
-
#logging_level ⇒ String
Logging levels include
ERROR,INFO, orNONE. -
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
-
#tags ⇒ Array<Types::Tag>
A map of tags assigned to a resource.
-
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
-
#team_name ⇒ String
The name of the Microsoft Teams Team.
-
#tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
-
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
Instance Attribute Details
#channel_id ⇒ String
The ID of the Microsoft Teams channel.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#channel_name ⇒ String
The name of the Microsoft Teams channel.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#configuration_name ⇒ String
The name of the configuration.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed AdministratorAccess policy is applied by default if this is not set.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes. This is not the service-linked role.
For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#logging_level ⇒ String
Logging levels include ERROR, INFO, or NONE.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of tags assigned to a resource. A tag is a string-to-string map of key-value pairs.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
To get the team ID, you must perform the initial authorization flow with Microsoft Teams in the AWS Chatbot console. Then you can copy and paste the team ID from the console. For more information, see
- Step 1: Configure a Microsoft Teams client][1
-
in the <i> AWS
Chatbot Administrator Guide</i>.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/teams-setup.html#teams-client-setup
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#team_name ⇒ String
The name of the Microsoft Teams Team.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-chatbot/types.rb', line 423 class CreateTeamsChannelConfigurationRequest < Struct.new( :channel_id, :channel_name, :team_id, :team_name, :tenant_id, :sns_topic_arns, :iam_role_arn, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:channel_name, :team_name] include Aws::Structure end |