Class: Aws::Chatbot::Types::DescribeChimeWebhookConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chatbot/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#chat_configuration_arnString

An optional Amazon Resource Number (ARN) of a ChimeWebhookConfiguration to describe.

Returns:

  • (String)


728
729
730
731
732
733
734
# File 'lib/aws-sdk-chatbot/types.rb', line 728

class DescribeChimeWebhookConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :chat_configuration_arn)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


728
729
730
731
732
733
734
# File 'lib/aws-sdk-chatbot/types.rb', line 728

class DescribeChimeWebhookConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :chat_configuration_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Returns:

  • (String)


728
729
730
731
732
733
734
# File 'lib/aws-sdk-chatbot/types.rb', line 728

class DescribeChimeWebhookConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :chat_configuration_arn)
  SENSITIVE = []
  include Aws::Structure
end