Class: Aws::Chatbot::Types::DescribeChimeWebhookConfigurationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeChimeWebhookConfigurationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional token returned from a prior request.
-
#webhook_configurations ⇒ Array<Types::ChimeWebhookConfiguration>
A list of Amazon Chime webhooks associated with the account.
Instance Attribute Details
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
749 750 751 752 753 754 |
# File 'lib/aws-sdk-chatbot/types.rb', line 749 class DescribeChimeWebhookConfigurationsResult < Struct.new( :next_token, :webhook_configurations) SENSITIVE = [] include Aws::Structure end |
#webhook_configurations ⇒ Array<Types::ChimeWebhookConfiguration>
A list of Amazon Chime webhooks associated with the account.
749 750 751 752 753 754 |
# File 'lib/aws-sdk-chatbot/types.rb', line 749 class DescribeChimeWebhookConfigurationsResult < Struct.new( :next_token, :webhook_configurations) SENSITIVE = [] include Aws::Structure end |