Class: Aws::Chatbot::Types::DescribeSlackChannelConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeSlackChannelConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#chat_configuration_arn ⇒ String
An optional Amazon Resource Number (ARN) of a SlackChannelConfiguration to describe.
-
#max_results ⇒ Integer
The maximum number of results to include in the response.
-
#next_token ⇒ String
An optional token returned from a prior request.
Instance Attribute Details
#chat_configuration_arn ⇒ String
An optional Amazon Resource Number (ARN) of a SlackChannelConfiguration to describe.
791 792 793 794 795 796 797 |
# File 'lib/aws-sdk-chatbot/types.rb', line 791 class DescribeSlackChannelConfigurationsRequest < Struct.new( :max_results, :next_token, :chat_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.
791 792 793 794 795 796 797 |
# File 'lib/aws-sdk-chatbot/types.rb', line 791 class DescribeSlackChannelConfigurationsRequest < Struct.new( :max_results, :next_token, :chat_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
791 792 793 794 795 796 797 |
# File 'lib/aws-sdk-chatbot/types.rb', line 791 class DescribeSlackChannelConfigurationsRequest < Struct.new( :max_results, :next_token, :chat_configuration_arn) SENSITIVE = [] include Aws::Structure end |