Class: Aws::Chatbot::Types::DescribeSlackChannelConfigurationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chatbot/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Returns:

  • (String)


812
813
814
815
816
817
# File 'lib/aws-sdk-chatbot/types.rb', line 812

class DescribeSlackChannelConfigurationsResult < Struct.new(
  :next_token,
  :slack_channel_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#slack_channel_configurationsArray<Types::SlackChannelConfiguration>

A list of Slack channel configurations.



812
813
814
815
816
817
# File 'lib/aws-sdk-chatbot/types.rb', line 812

class DescribeSlackChannelConfigurationsResult < Struct.new(
  :next_token,
  :slack_channel_configurations)
  SENSITIVE = []
  include Aws::Structure
end