Class: Aws::Chatbot::Types::DescribeSlackUserIdentitiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeSlackUserIdentitiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration associated with the user identities to describe.
-
#max_results ⇒ Integer
The maximum number of results to include in the response.
-
#next_token ⇒ String
An optional token returned from a prior request.
Instance Attribute Details
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration associated with the user identities to describe.
854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-chatbot/types.rb', line 854 class DescribeSlackUserIdentitiesRequest < Struct.new( :chat_configuration_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.
854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-chatbot/types.rb', line 854 class DescribeSlackUserIdentitiesRequest < Struct.new( :chat_configuration_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-chatbot/types.rb', line 854 class DescribeSlackUserIdentitiesRequest < Struct.new( :chat_configuration_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |