Class: Aws::Chatbot::Types::DescribeSlackUserIdentitiesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chatbot/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.

Returns:

  • (String)


875
876
877
878
879
880
# File 'lib/aws-sdk-chatbot/types.rb', line 875

class DescribeSlackUserIdentitiesResult < Struct.new(
  :slack_user_identities,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#slack_user_identitiesArray<Types::SlackUserIdentity>

A list of Slack User Identities.

Returns:



875
876
877
878
879
880
# File 'lib/aws-sdk-chatbot/types.rb', line 875

class DescribeSlackUserIdentitiesResult < Struct.new(
  :slack_user_identities,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end