Class: Aws::Chatbot::Types::DescribeSlackWorkspacesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeSlackWorkspacesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional token returned from a prior request.
-
#slack_workspaces ⇒ Array<Types::SlackWorkspace>
A list of Slack workspaces registered with AWS Chatbot.
Instance Attribute Details
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
932 933 934 935 936 937 |
# File 'lib/aws-sdk-chatbot/types.rb', line 932 class DescribeSlackWorkspacesResult < Struct.new( :slack_workspaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#slack_workspaces ⇒ Array<Types::SlackWorkspace>
A list of Slack workspaces registered with AWS Chatbot.
932 933 934 935 936 937 |
# File 'lib/aws-sdk-chatbot/types.rb', line 932 class DescribeSlackWorkspacesResult < Struct.new( :slack_workspaces, :next_token) SENSITIVE = [] include Aws::Structure end |