Class: Aws::Chatbot::Types::SlackChannelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::SlackChannelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
An AWS Chatbot configuration for Slack.
Constant Summary collapse
- SENSITIVE =
[:slack_channel_name]
Instance Attribute Summary collapse
-
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration.
-
#configuration_name ⇒ String
The name of the configuration.
-
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails.
-
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes.
-
#logging_level ⇒ String
Logging levels include
ERROR,INFO, orNONE. -
#slack_channel_id ⇒ String
The ID of the Slack channel.
-
#slack_channel_name ⇒ String
The name of the Slack channel.
-
#slack_team_id ⇒ String
The ID of the Slack workspace authorized with Amazon Chime.
-
#slack_team_name ⇒ String
Name of the Slack workspace.
-
#sns_topic_arns ⇒ Array<String>
The ARNs of the SNS topics that deliver notifications to AWS Chatbot.
-
#tags ⇒ Array<Types::Tag>
A map of tags assigned to a resource.
-
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
Instance Attribute Details
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#configuration_name ⇒ String
The name of the configuration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed AdministratorAccess policy is applied by default if this is not set.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes. This is not the service-linked role.
For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#logging_level ⇒ String
Logging levels include ERROR, INFO, or NONE.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_channel_id ⇒ String
The ID of the Slack channel.
To get this ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_channel_name ⇒ String
The name of the Slack channel.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_team_id ⇒ String
The ID of the Slack workspace authorized with Amazon Chime.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_team_name ⇒ String
Name of the Slack workspace.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#sns_topic_arns ⇒ Array<String>
The ARNs of the SNS topics that deliver notifications to AWS Chatbot.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A map of tags assigned to a resource. A tag is a string-to-string map of key-value pairs.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1381 class SlackChannelConfiguration < Struct.new( :slack_team_name, :slack_team_id, :slack_channel_id, :slack_channel_name, :chat_configuration_arn, :iam_role_arn, :sns_topic_arns, :configuration_name, :logging_level, :guardrail_policy_arns, :user_authorization_required, :tags) SENSITIVE = [:slack_channel_name] include Aws::Structure end |