Method: Aws::Chatbot::Types::SlackChannelConfiguration#slack_channel_id

Defined in:
lib/aws-sdk-chatbot/types.rb

#slack_channel_idString

The ID of the Slack channel.

To get this ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.

Returns:

  • (String)


1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
# File 'lib/aws-sdk-chatbot/types.rb', line 1785

class SlackChannelConfiguration < Struct.new(
  :slack_team_name,
  :slack_team_id,
  :slack_channel_id,
  :slack_channel_name,
  :chat_configuration_arn,
  :iam_role_arn,
  :sns_topic_arns,
  :configuration_name,
  :logging_level,
  :guardrail_policy_arns,
  :user_authorization_required,
  :tags,
  :state,
  :state_reason)
  SENSITIVE = [:slack_channel_name]
  include Aws::Structure
end