Class: Aws::Chatbot::Types::TeamsUserIdentity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::TeamsUserIdentity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Identifes a user level permission for a channel configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_user_identity ⇒ String
The AWS user identity ARN used to associate a Microsoft Teams user Identity with an IAM Role.
-
#chat_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the MicrosoftTeamsChannelConfiguration associated with the user identity to delete.
-
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes.
-
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
-
#teams_channel_id ⇒ String
The ID of the Microsoft Teams channel.
-
#teams_tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
-
#user_id ⇒ String
The Microsoft Teams user ID.
Instance Attribute Details
#aws_user_identity ⇒ String
The AWS user identity ARN used to associate a Microsoft Teams user Identity with an IAM Role.
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#chat_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the MicrosoftTeamsChannelConfiguration associated with the user identity to delete.
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes. This is not the service-linked role.
For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
To get the team ID, you must perform the initial authorization flow with Microsoft Teams in the AWS Chatbot console. Then you can copy and paste the team ID from the console. For more information, see
- Step 1: Configure a Microsoft Teams client][1
-
in the <i> AWS
Chatbot Administrator Guide</i>.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/teams-setup.html#teams-client-setup
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#teams_channel_id ⇒ String
The ID of the Microsoft Teams channel.
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#teams_tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The Microsoft Teams user ID.
1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1663 class TeamsUserIdentity < Struct.new( :iam_role_arn, :chat_configuration_arn, :team_id, :user_id, :aws_user_identity, :teams_channel_id, :teams_tenant_id) SENSITIVE = [] include Aws::Structure end |