Class: Aws::Chatbot::Types::UpdateAccountPreferencesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::UpdateAccountPreferencesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#training_data_collection_enabled ⇒ Boolean
Turns on training data collection.
-
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
Instance Attribute Details
#training_data_collection_enabled ⇒ Boolean
Turns on training data collection.
This helps improve the AWS Chatbot experience by allowing AWS Chatbot to store and use your customer information, such as AWS Chatbot configurations, notifications, user inputs, AWS Chatbot generated responses, and interaction data. This data helps us to continuously improve and develop Artificial Intelligence (AI) technologies. Your data is not shared with any third parties and is protected using sophisticated controls to prevent unauthorized access and misuse. AWS Chatbot does not store or use interactions in chat channels with Amazon Q for training AI technologies for AWS Chatbot.
1748 1749 1750 1751 1752 1753 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1748 class UpdateAccountPreferencesRequest < Struct.new( :user_authorization_required, :training_data_collection_enabled) SENSITIVE = [] include Aws::Structure end |
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
1748 1749 1750 1751 1752 1753 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1748 class UpdateAccountPreferencesRequest < Struct.new( :user_authorization_required, :training_data_collection_enabled) SENSITIVE = [] include Aws::Structure end |