Class: Aws::Chatbot::Types::UpdateTeamsChannelConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::UpdateTeamsChannelConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:channel_name]
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID of the Microsoft Teams channel.
-
#channel_name ⇒ String
The name of the Microsoft Teams channel.
-
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the TeamsChannelConfiguration to update.
-
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails.
-
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes.
-
#logging_level ⇒ String
Logging levels include
ERROR,INFO, orNONE. -
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
-
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
Instance Attribute Details
#channel_id ⇒ String
The ID of the Microsoft Teams channel.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#channel_name ⇒ String
The name of the Microsoft Teams channel.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the TeamsChannelConfiguration to update.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed AdministratorAccess policy is applied by default if this is not set.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes. This is not the service-linked role.
For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#logging_level ⇒ String
Logging levels include ERROR, INFO, or NONE.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1997 class UpdateTeamsChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :channel_id, :channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:channel_name] include Aws::Structure end |