Class: Aws::Chatbot::Types::ConfiguredTeam
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::ConfiguredTeam
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
A Microsoft Teams team that is authorized with AWS Chatbot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
-
#team_name ⇒ String
The name of the Microsoft Teams Team.
-
#tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
Instance Attribute Details
#team_id ⇒ String
The ID of the Microsoft Teams authorized with AWS Chatbot.
To get the team ID, you must perform the initial authorization flow with Microsoft Teams in the AWS Chatbot console. Then you can copy and paste the team ID from the console. For more information, see
- Step 1: Configure a Microsoft Teams client][1
-
in the <i> AWS
Chatbot Administrator Guide</i>.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/teams-setup.html#teams-client-setup
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-chatbot/types.rb', line 131 class ConfiguredTeam < Struct.new( :tenant_id, :team_id, :team_name) SENSITIVE = [] include Aws::Structure end |
#team_name ⇒ String
The name of the Microsoft Teams Team.
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-chatbot/types.rb', line 131 class ConfiguredTeam < Struct.new( :tenant_id, :team_id, :team_name) SENSITIVE = [] include Aws::Structure end |
#tenant_id ⇒ String
The ID of the Microsoft Teams tenant.
131 132 133 134 135 136 137 |
# File 'lib/aws-sdk-chatbot/types.rb', line 131 class ConfiguredTeam < Struct.new( :tenant_id, :team_id, :team_name) SENSITIVE = [] include Aws::Structure end |