Class: Aws::Chatbot::Types::DescribeSlackChannelConfigurationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeSlackChannelConfigurationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional token returned from a prior request.
-
#slack_channel_configurations ⇒ Array<Types::SlackChannelConfiguration>
A list of Slack channel configurations.
Instance Attribute Details
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
812 813 814 815 816 817 |
# File 'lib/aws-sdk-chatbot/types.rb', line 812 class DescribeSlackChannelConfigurationsResult < Struct.new( :next_token, :slack_channel_configurations) SENSITIVE = [] include Aws::Structure end |
#slack_channel_configurations ⇒ Array<Types::SlackChannelConfiguration>
A list of Slack channel configurations.
812 813 814 815 816 817 |
# File 'lib/aws-sdk-chatbot/types.rb', line 812 class DescribeSlackChannelConfigurationsResult < Struct.new( :next_token, :slack_channel_configurations) SENSITIVE = [] include Aws::Structure end |