Method: Aws::Chatbot::Types::DescribeSlackUserIdentitiesRequest#max_results
- Defined in:
- lib/aws-sdk-chatbot/types.rb
#max_results ⇒ Integer
The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.
1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1109 class DescribeSlackUserIdentitiesRequest < Struct.new( :chat_configuration_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |