Class: Aws::Chatbot::Types::DescribeSlackUserIdentitiesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::DescribeSlackUserIdentitiesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional token returned from a prior request.
-
#slack_user_identities ⇒ Array<Types::SlackUserIdentity>
A list of Slack User Identities.
Instance Attribute Details
#next_token ⇒ String
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.
875 876 877 878 879 880 |
# File 'lib/aws-sdk-chatbot/types.rb', line 875 class DescribeSlackUserIdentitiesResult < Struct.new( :slack_user_identities, :next_token) SENSITIVE = [] include Aws::Structure end |
#slack_user_identities ⇒ Array<Types::SlackUserIdentity>
A list of Slack User Identities.
875 876 877 878 879 880 |
# File 'lib/aws-sdk-chatbot/types.rb', line 875 class DescribeSlackUserIdentitiesResult < Struct.new( :slack_user_identities, :next_token) SENSITIVE = [] include Aws::Structure end |