Class: Aws::Chatbot::Types::UpdateSlackChannelConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chatbot::Types::UpdateSlackChannelConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chatbot/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:slack_channel_name]
Instance Attribute Summary collapse
-
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration to update.
-
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails.
-
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes.
-
#logging_level ⇒ String
Logging levels include
ERROR,INFO, orNONE. -
#slack_channel_id ⇒ String
The ID of the Slack channel.
-
#slack_channel_name ⇒ String
The name of the Slack channel.
-
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
-
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
Instance Attribute Details
#chat_configuration_arn ⇒ String
The Amazon Resource Number (ARN) of the SlackChannelConfiguration to update.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#guardrail_policy_arns ⇒ Array<String>
The list of IAM policy ARNs that are applied as channel guardrails. The AWS managed AdministratorAccess policy is applied by default if this is not set.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#iam_role_arn ⇒ String
A user-defined role that AWS Chatbot assumes. This is not the service-linked role.
For more information, see [IAM policies for AWS Chatbot] in the AWS Chatbot Administrator Guide.
[1]: docs.aws.amazon.com/chatbot/latest/adminguide/chatbot-iam-policies.html
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#logging_level ⇒ String
Logging levels include ERROR, INFO, or NONE.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_channel_id ⇒ String
The ID of the Slack channel.
To get this ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#slack_channel_name ⇒ String
The name of the Slack channel.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#sns_topic_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the SNS topics that deliver notifications to AWS Chatbot.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |
#user_authorization_required ⇒ Boolean
Enables use of a user role requirement in your chat configuration.
1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 |
# File 'lib/aws-sdk-chatbot/types.rb', line 1912 class UpdateSlackChannelConfigurationRequest < Struct.new( :chat_configuration_arn, :slack_channel_id, :slack_channel_name, :sns_topic_arns, :iam_role_arn, :logging_level, :guardrail_policy_arns, :user_authorization_required) SENSITIVE = [:slack_channel_name] include Aws::Structure end |